/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module appstream.Artifact;

private import appstream.Checksum;
private import appstream.c.functions;
public  import appstream.c.types;
private import glib.ConstructionException;
private import glib.PtrArray;
private import glib.Str;
private import gobject.ObjectG;


/** */
public class Artifact : ObjectG
{
	/** the main Gtk struct */
	protected AsArtifact* asArtifact;

	/** Get the main Gtk struct */
	public AsArtifact* getArtifactStruct(bool transferOwnership = false)
	{
		if (transferOwnership)
			ownedRef = false;
		return asArtifact;
	}

	/** the main Gtk struct as a void* */
	protected override void* getStruct()
	{
		return cast(void*)asArtifact;
	}

	/**
	 * Sets our main struct and passes it to the parent class.
	 */
	public this (AsArtifact* asArtifact, bool ownedRef = false)
	{
		this.asArtifact = asArtifact;
		super(cast(GObject*)asArtifact, ownedRef);
	}


	/** */
	public static GType getType()
	{
		return as_artifact_get_type();
	}

	/**
	 * Creates a new #AsArtifact.
	 *
	 * Returns: a #AsArtifact
	 *
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this()
	{
		auto __p = as_artifact_new();

		if(__p is null)
		{
			throw new ConstructionException("null returned by new");
		}

		this(cast(AsArtifact*) __p, true);
	}

	/**
	 * Add a checksum for the file associated with this artifact.
	 *
	 * Params:
	 *     cs = The #AsChecksum.
	 */
	public void addChecksum(Checksum cs)
	{
		as_artifact_add_checksum(asArtifact, (cs is null) ? null : cs.getChecksumStruct());
	}

	/**
	 * Adds a artifact location.
	 *
	 * Params:
	 *     location = An URL of the download location
	 */
	public void addLocation(string location)
	{
		as_artifact_add_location(asArtifact, Str.toStringz(location));
	}

	/**
	 * Gets the bundle kind of this artifact.
	 *
	 * Returns: the #AsBundleKind
	 */
	public AsBundleKind getBundleKind()
	{
		return as_artifact_get_bundle_kind(asArtifact);
	}

	/**
	 * Gets the artifact checksum
	 *
	 * Returns: an #AsChecksum, or %NULL for not set or invalid
	 */
	public Checksum getChecksum(AsChecksumKind kind)
	{
		auto __p = as_artifact_get_checksum(asArtifact, kind);

		if(__p is null)
		{
			return null;
		}

		return ObjectG.getDObject!(Checksum)(cast(AsChecksum*) __p);
	}

	/**
	 * Get a list of all checksums we have for this artifact.
	 *
	 * Returns: an array of #AsChecksum objects.
	 */
	public PtrArray getChecksums()
	{
		auto __p = as_artifact_get_checksums(asArtifact);

		if(__p is null)
		{
			return null;
		}

		return new PtrArray(cast(GPtrArray*) __p);
	}

	/**
	 * Gets a suggested filename for the downloaded artifact,
	 * or %NULL if none is suggested.
	 *
	 * Returns: The platform triplet or identifier string.
	 */
	public string getFilename()
	{
		return Str.toString(as_artifact_get_filename(asArtifact));
	}

	/**
	 * Gets the artifact kind.
	 *
	 * Returns: the #AsArtifactKind
	 */
	public AsArtifactKind getKind()
	{
		return as_artifact_get_kind(asArtifact);
	}

	/**
	 * Gets the artifact locations, typically URLs.
	 *
	 * Returns: list of locations
	 */
	public PtrArray getLocations()
	{
		auto __p = as_artifact_get_locations(asArtifact);

		if(__p is null)
		{
			return null;
		}

		return new PtrArray(cast(GPtrArray*) __p);
	}

	/**
	 * Gets the artifact platform string (e.g. a triplet like "x86_64-linux-gnu").
	 *
	 * Returns: The platform triplet or identifier string.
	 */
	public string getPlatform()
	{
		return Str.toString(as_artifact_get_platform(asArtifact));
	}

	/**
	 * Gets the artifact size.
	 *
	 * Params:
	 *     kind = a #AsSizeKind
	 *
	 * Returns: The size of the given kind of this artifact.
	 */
	public ulong getSize(AsSizeKind kind)
	{
		return as_artifact_get_size(asArtifact, kind);
	}

	/**
	 * Sets the bundle kind for this release artifact.
	 *
	 * Params:
	 *     kind = the #AsBundleKind, e.g. %AS_BUNDLE_KIND_TARBALL.
	 */
	public void setBundleKind(AsBundleKind kind)
	{
		as_artifact_set_bundle_kind(asArtifact, kind);
	}

	/**
	 * Sets a suggested filename for this artifact after it has been downloaded.
	 *
	 * Params:
	 *     filename = the file name suggestion.
	 */
	public void setFilename(string filename)
	{
		as_artifact_set_filename(asArtifact, Str.toStringz(filename));
	}

	/**
	 * Sets the artifact kind.
	 *
	 * Params:
	 *     kind = the #AsArtifactKind, e.g. %AS_ARTIFACT_KIND_SOURCE.
	 */
	public void setKind(AsArtifactKind kind)
	{
		as_artifact_set_kind(asArtifact, kind);
	}

	/**
	 * Sets the artifact platform triplet or identifier string.
	 *
	 * Params:
	 *     platform = the platform triplet.
	 */
	public void setPlatform(string platform)
	{
		as_artifact_set_platform(asArtifact, Str.toStringz(platform));
	}

	/**
	 * Sets the artifact size for the given kind.
	 *
	 * Params:
	 *     size = a size in bytes, or 0 for unknown
	 *     kind = a #AsSizeKind
	 */
	public void setSize(ulong size, AsSizeKind kind)
	{
		as_artifact_set_size(asArtifact, size, kind);
	}
}
