/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module appstream.Review;

private import appstream.c.functions;
public  import appstream.c.types;
private import glib.ConstructionException;
private import glib.DateTime;
private import glib.Str;
private import gobject.ObjectG;


/** */
public class Review : ObjectG
{
	/** the main Gtk struct */
	protected AsReview* asReview;

	/** Get the main Gtk struct */
	public AsReview* getReviewStruct(bool transferOwnership = false)
	{
		if (transferOwnership)
			ownedRef = false;
		return asReview;
	}

	/** the main Gtk struct as a void* */
	protected override void* getStruct()
	{
		return cast(void*)asReview;
	}

	/**
	 * Sets our main struct and passes it to the parent class.
	 */
	public this (AsReview* asReview, bool ownedRef = false)
	{
		this.asReview = asReview;
		super(cast(GObject*)asReview, ownedRef);
	}


	/** */
	public static GType getType()
	{
		return as_review_get_type();
	}

	/**
	 * Creates a new #AsReview.
	 *
	 * Returns: a #AsReview
	 *
	 * Since: 0.14.0
	 *
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this()
	{
		auto __p = as_review_new();

		if(__p is null)
		{
			throw new ConstructionException("null returned by new");
		}

		this(cast(AsReview*) __p, true);
	}

	/**
	 * Adds flags to an existing review without replacing the other flags.
	 *
	 * Params:
	 *     flags = a #AsReviewFlags, e.g. %AS_REVIEW_FLAG_SELF
	 *
	 * Since: 0.14.0
	 */
	public void addFlags(AsReviewFlags flags)
	{
		as_review_add_flags(asReview, flags);
	}

	/**
	 * Adds metadata to the review object.
	 * It is left for the the plugin to use this method as required, but a
	 * typical use would be to store some secure authentication token.
	 *
	 * Params:
	 *     key = a string
	 *     value = a string
	 *
	 * Since: 0.14.0
	 */
	public void addMetadata(string key, string value)
	{
		as_review_add_metadata(asReview, Str.toStringz(key), Str.toStringz(value));
	}

	/**
	 * Checks if two reviews are the same.
	 *
	 * Params:
	 *     review2 = a #AsReview instance.
	 *
	 * Returns: %TRUE for success
	 *
	 * Since: 0.14.0
	 */
	public bool equal(Review review2)
	{
		return as_review_equal(asReview, (review2 is null) ? null : review2.getReviewStruct()) != 0;
	}

	/**
	 * Gets the date the review was originally submitted.
	 *
	 * Returns: the #GDateTime, or %NULL for unset
	 *
	 * Since: 0.14.0
	 */
	public DateTime getDate()
	{
		auto __p = as_review_get_date(asReview);

		if(__p is null)
		{
			return null;
		}

		return new DateTime(cast(GDateTime*) __p);
	}

	/**
	 * Gets the multi-line review text that forms the body of the review.
	 *
	 * Returns: the string, or %NULL
	 *
	 * Since: 0.14.0
	 */
	public string getDescription()
	{
		return Str.toString(as_review_get_description(asReview));
	}

	/**
	 * Gets any flags set on the review, for example if the user has already
	 * voted on the review or if the user wrote the review themselves.
	 *
	 * Returns: a #AsReviewFlags, e.g. %AS_REVIEW_FLAG_SELF
	 *
	 * Since: 0.14.0
	 */
	public AsReviewFlags getFlags()
	{
		return as_review_get_flags(asReview);
	}

	/**
	 * Gets the review id.
	 *
	 * Returns: the review identifier, e.g. "deadbeef"
	 *
	 * Since: 0.14.0
	 */
	public string getId()
	{
		return Str.toString(as_review_get_id(asReview));
	}

	/**
	 * Gets the locale for the review.
	 *
	 * Returns: the string, or %NULL
	 *
	 * Since: 0.14.0
	 */
	public string getLocale()
	{
		return Str.toString(as_review_get_locale(asReview));
	}

	/**
	 * Gets some metadata from a review object.
	 * It is left for the the plugin to use this method as required, but a
	 * typical use would be to retrieve some secure authentication token.
	 *
	 * Params:
	 *     key = a string
	 *
	 * Returns: A string value, or %NULL for not found
	 *
	 * Since: 0.14.0
	 */
	public string getMetadataItem(string key)
	{
		return Str.toString(as_review_get_metadata_item(asReview, Str.toStringz(key)));
	}

	/**
	 * This allows the UI to sort reviews into the correct order.
	 * Higher numbers indicate a more important or relevant review.
	 *
	 * Returns: the review priority, or 0 for unset.
	 *
	 * Since: 0.14.0
	 */
	public int getPriority()
	{
		return as_review_get_priority(asReview);
	}

	/**
	 * Gets the star rating of the review, where 100 is 5 stars.
	 *
	 * Returns: integer as a percentage, or 0 for unset
	 *
	 * Since: 0.14.0
	 */
	public int getRating()
	{
		return as_review_get_rating(asReview);
	}

	/**
	 * Gets the name of the reviewer.
	 *
	 * Returns: the reviewer ID, e.g. "deadbeef", or %NULL
	 *
	 * Since: 0.14.0
	 */
	public string getReviewerId()
	{
		return Str.toString(as_review_get_reviewer_id(asReview));
	}

	/**
	 * Gets the name of the reviewer.
	 *
	 * Returns: the reviewer name, e.g. "David Smith", or %NULL
	 *
	 * Since: 0.14.0
	 */
	public string getReviewerName()
	{
		return Str.toString(as_review_get_reviewer_name(asReview));
	}

	/**
	 * Gets the review summary.
	 *
	 * Returns: the one-line summary, e.g. "Awesome application"
	 *
	 * Since: 0.14.0
	 */
	public string getSummary()
	{
		return Str.toString(as_review_get_summary(asReview));
	}

	/**
	 * Gets the version string for the application being reviewed..
	 *
	 * Returns: the version string, e.g. "0.1.2", or %NULL for unset
	 *
	 * Since: 0.14.0
	 */
	public string getVersion()
	{
		return Str.toString(as_review_get_version(asReview));
	}

	/**
	 * Sets the date the review was originally submitted.
	 *
	 * Params:
	 *     date = a #GDateTime, or %NULL
	 *
	 * Since: 0.14.0
	 */
	public void setDate(DateTime date)
	{
		as_review_set_date(asReview, (date is null) ? null : date.getDateTimeStruct());
	}

	/**
	 * Sets the multi-line review text that forms the body of the review.
	 *
	 * Params:
	 *     description = multi-line description
	 *
	 * Since: 0.14.0
	 */
	public void setDescription(string description)
	{
		as_review_set_description(asReview, Str.toStringz(description));
	}

	/**
	 * Gets any flags set on the review, for example if the user has already
	 * voted on the review or if the user wrote the review themselves.
	 *
	 * Params:
	 *     flags = a #AsReviewFlags, e.g. %AS_REVIEW_FLAG_SELF
	 *
	 * Since: 0.14.0
	 */
	public void setFlags(AsReviewFlags flags)
	{
		as_review_set_flags(asReview, flags);
	}

	/**
	 * Sets the review identifier that is unique to each review.
	 *
	 * Params:
	 *     id = review identifier, e.g. "deadbeef"
	 *
	 * Since: 0.14.0
	 */
	public void setId(string id)
	{
		as_review_set_id(asReview, Str.toStringz(id));
	}

	/**
	 * Sets the locale for the review.
	 *
	 * Params:
	 *     locale = locale, e.g. "en_GB"
	 *
	 * Since: 0.14.0
	 */
	public void setLocale(string locale)
	{
		as_review_set_locale(asReview, Str.toStringz(locale));
	}

	/**
	 * Sets the priority for the review, where positive numbers indicate
	 * a better review for the specific user.
	 *
	 * Params:
	 *     priority = a priority value
	 *
	 * Since: 0.14.0
	 */
	public void setPriority(int priority)
	{
		as_review_set_priority(asReview, priority);
	}

	/**
	 * Sets the star rating of the review, where 100 is 5 stars..
	 *
	 * Params:
	 *     rating = a integer as a percentage, or 0 for unset
	 *
	 * Since: 0.14.0
	 */
	public void setRating(int rating)
	{
		as_review_set_rating(asReview, rating);
	}

	/**
	 * Sets the name of the reviewer, which can be left unset.
	 *
	 * Params:
	 *     reviewerId = the reviewer ID, e.g. "deadbeef"
	 *
	 * Since: 0.14.0
	 */
	public void setReviewerId(string reviewerId)
	{
		as_review_set_reviewer_id(asReview, Str.toStringz(reviewerId));
	}

	/**
	 * Sets the name of the reviewer, which can be left unset.
	 *
	 * Params:
	 *     reviewerName = the reviewer name, e.g. "David Smith"
	 *
	 * Since: 0.14.0
	 */
	public void setReviewerName(string reviewerName)
	{
		as_review_set_reviewer_name(asReview, Str.toStringz(reviewerName));
	}

	/**
	 * Sets the one-line summary that may be displayed in bold.
	 *
	 * Params:
	 *     summary = a one-line summary, e.g. "Awesome application"
	 *
	 * Since: 0.14.0
	 */
	public void setSummary(string summary)
	{
		as_review_set_summary(asReview, Str.toStringz(summary));
	}

	/**
	 * Sets the version string for the application being reviewed.
	 *
	 * Params:
	 *     version_ = a version string, e.g. "0.1.2"
	 *
	 * Since: 0.14.0
	 */
	public void setVersion(string version_)
	{
		as_review_set_version(asReview, Str.toStringz(version_));
	}
}
