/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module ascompose.Canvas;

private import ascompose.Font;
private import ascompose.c.functions;
public  import ascompose.c.types;
private import gio.InputStream;
private import glib.ConstructionException;
private import glib.ErrorG;
private import glib.GException;
private import glib.Str;
private import gobject.ObjectG;


/** */
public class Canvas : ObjectG
{
	/** the main Gtk struct */
	protected AscCanvas* ascCanvas;

	/** Get the main Gtk struct */
	public AscCanvas* getCanvasStruct(bool transferOwnership = false)
	{
		if (transferOwnership)
			ownedRef = false;
		return ascCanvas;
	}

	/** the main Gtk struct as a void* */
	protected override void* getStruct()
	{
		return cast(void*)ascCanvas;
	}

	/**
	 * Sets our main struct and passes it to the parent class.
	 */
	public this (AscCanvas* ascCanvas, bool ownedRef = false)
	{
		this.ascCanvas = ascCanvas;
		super(cast(GObject*)ascCanvas, ownedRef);
	}


	/** */
	public static GType getType()
	{
		return asc_canvas_get_type();
	}

	/**
	 * Creates a new #AscFont.
	 *
	 * Returns: an #AscCanvas
	 *
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this(int width, int height)
	{
		auto __p = asc_canvas_new(width, height);

		if(__p is null)
		{
			throw new ConstructionException("null returned by new");
		}

		this(cast(AscCanvas*) __p, true);
	}

	/**
	 * Draw a longer text with linebreaks.
	 *
	 * Params:
	 *     font = an #AscFont to use for drawing the text.
	 *     borderWidth = Border with around the text (set to -1 to use defaults).
	 *     linePad = Padding between lines (set to -1 to use defaults).
	 *
	 * Throws: GException on failure.
	 */
	public bool drawText(Font font, string text, int borderWidth, int linePad)
	{
		GError* err = null;

		auto __p = asc_canvas_draw_text(ascCanvas, (font is null) ? null : font.getFontStruct(), Str.toStringz(text), borderWidth, linePad, &err) != 0;

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		return __p;
	}

	/**
	 * Draw a simple line of text without linebreaks to fill the canvas.
	 *
	 * Params:
	 *     font = an #AscFont to use for drawing the text.
	 *     borderWidth = Border with around the text, set to -1 to use defaults.
	 *
	 * Throws: GException on failure.
	 */
	public bool drawTextLine(Font font, string text, int borderWidth)
	{
		GError* err = null;

		auto __p = asc_canvas_draw_text_line(ascCanvas, (font is null) ? null : font.getFontStruct(), Str.toStringz(text), borderWidth, &err) != 0;

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		return __p;
	}

	/**
	 * Gets the canvas height.
	 */
	public uint getHeight()
	{
		return asc_canvas_get_height(ascCanvas);
	}

	/**
	 * Gets the canvas width.
	 */
	public uint getWidth()
	{
		return asc_canvas_get_width(ascCanvas);
	}

	/**
	 * Render an SVG graphic from the SVG data provided.
	 *
	 * Params:
	 *     stream = SVG data input stream.
	 *
	 * Throws: GException on failure.
	 */
	public bool renderSvg(InputStream stream)
	{
		GError* err = null;

		auto __p = asc_canvas_render_svg(ascCanvas, (stream is null) ? null : stream.getInputStreamStruct(), &err) != 0;

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		return __p;
	}

	/**
	 * Save canvas to PNG file.
	 *
	 * Params:
	 *     fname = Filename to save to.
	 *
	 * Throws: GException on failure.
	 */
	public bool savePng(string fname)
	{
		GError* err = null;

		auto __p = asc_canvas_save_png(ascCanvas, Str.toStringz(fname), &err) != 0;

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		return __p;
	}
}
