/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module ascompose.Font;

private import ascompose.c.functions;
public  import ascompose.c.types;
private import glib.ConstructionException;
private import glib.ErrorG;
private import glib.GException;
private import glib.ListG;
private import glib.Str;
private import gobject.ObjectG;


/** */
public class Font : ObjectG
{
	/** the main Gtk struct */
	protected AscFont* ascFont;

	/** Get the main Gtk struct */
	public AscFont* getFontStruct(bool transferOwnership = false)
	{
		if (transferOwnership)
			ownedRef = false;
		return ascFont;
	}

	/** the main Gtk struct as a void* */
	protected override void* getStruct()
	{
		return cast(void*)ascFont;
	}

	/**
	 * Sets our main struct and passes it to the parent class.
	 */
	public this (AscFont* ascFont, bool ownedRef = false)
	{
		this.ascFont = ascFont;
		super(cast(GObject*)ascFont, ownedRef);
	}


	/** */
	public static GType getType()
	{
		return asc_font_get_type();
	}

	/**
	 * Creates a new #AscFont from data in memory.
	 * The font file basename needs to be supplied as fallback
	 * and for heuristics.
	 *
	 * Params:
	 *     data = Data to load.
	 *     len = Length of the data to load.
	 *     fileBasename = Font file basename.
	 *
	 * Throws: GException on failure.
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this(void* data, ptrdiff_t len, string fileBasename)
	{
		GError* err = null;

		auto __p = asc_font_new_from_data(data, len, Str.toStringz(fileBasename), &err);

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		if(__p is null)
		{
			throw new ConstructionException("null returned by new_from_data");
		}

		this(cast(AscFont*) __p, true);
	}

	/**
	 * Creates a new #AscFont from a file on the filesystem.
	 *
	 * Params:
	 *     fname = Name of the file to load.
	 *
	 * Throws: GException on failure.
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this(string fname)
	{
		GError* err = null;

		auto __p = asc_font_new_from_file(Str.toStringz(fname), &err);

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		if(__p is null)
		{
			throw new ConstructionException("null returned by new_from_file");
		}

		this(cast(AscFont*) __p, true);
	}

	/**
	 * Add language to the language list of this font.
	 */
	public void addLanguage(string lang)
	{
		asc_font_add_language(ascFont, Str.toStringz(lang));
	}

	/**
	 * Gets the font description.
	 */
	public string getDescription()
	{
		return Str.toString(asc_font_get_description(ascFont));
	}

	/**
	 * Gets the font family.
	 */
	public string getFamily()
	{
		return Str.toString(asc_font_get_family(ascFont));
	}

	/**
	 * Gets the fonts full name.
	 */
	public string getFullname()
	{
		return Str.toString(asc_font_get_fullname(ascFont));
	}

	/**
	 * Gets the font homepage.
	 */
	public string getHomepage()
	{
		return Str.toString(asc_font_get_homepage(ascFont));
	}

	/**
	 * Gets an identifier string for this font.
	 */
	public string getId()
	{
		return Str.toString(asc_font_get_id(ascFont));
	}

	/**
	 * Gets the list of languages supported by this font.
	 *
	 * Returns: Sorted list of languages
	 */
	public ListG getLanguageList()
	{
		auto __p = asc_font_get_language_list(ascFont);

		if(__p is null)
		{
			return null;
		}

		return new ListG(cast(GList*) __p);
	}

	/**
	 * Gets the fonts preferred language.
	 */
	public string getPreferredLanguage()
	{
		return Str.toString(asc_font_get_preferred_language(ascFont));
	}

	/**
	 * Gets the sample icon text fragment for this font.
	 */
	public string getSampleIconText()
	{
		return Str.toString(asc_font_get_sample_icon_text(ascFont));
	}

	/**
	 * Gets the sample text for this font.
	 */
	public string getSampleText()
	{
		return Str.toString(asc_font_get_sample_text(ascFont));
	}

	/**
	 * Gets the font style.
	 */
	public string getStyle()
	{
		return Str.toString(asc_font_get_style(ascFont));
	}

	/**
	 * Sets the fonts preferred language.
	 */
	public void setPreferredLanguage(string lang)
	{
		asc_font_set_preferred_language(ascFont, Str.toStringz(lang));
	}

	/**
	 * Sets the sample icon text fragment for this font - must not
	 * contain more than 3 characters to be valid.
	 */
	public void setSampleIconText(string text)
	{
		asc_font_set_sample_icon_text(ascFont, Str.toStringz(text));
	}

	/**
	 * Sets the sample text for this font.
	 */
	public void setSampleText(string text)
	{
		asc_font_set_sample_text(ascFont, Str.toStringz(text));
	}
}
