/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module ascompose.Globals;

private import ascompose.c.functions;
public  import ascompose.c.types;
private import glib.Str;


/** */
public struct Globals
{

	/**
	 * Get temporary directory used by appstream-compose.
	 */
	public static string getTmpDir()
	{
		return Str.toString(asc_globals_get_tmp_dir());
	}

	/**
	 * Get temporary directory used by appstream-compose
	 * and try to create it if it does not exist.
	 */
	public static string getTmpDirCreate()
	{
		return Str.toString(asc_globals_get_tmp_dir_create());
	}

	/**
	 * Set temporary directory used by appstream-compose.
	 */
	public static void setTmpDir(string path)
	{
		asc_globals_set_tmp_dir(Str.toStringz(path));
	}

	/**
	 * Get whether images should be optimized using optipng.
	 */
	public static bool useOptipng()
	{
		return asc_globals_get_use_optipng() != 0;
	}

	/**
	 * Set whether images should be optimized using optipng.
	 */
	public static void setUseOptipng(bool enabled)
	{
		asc_globals_set_use_optipng(enabled);
	}

	/**
	 * Get path to the "optipng" binary we should use.
	 */
	public static string optipngBinary()
	{
		return Str.toString(asc_globals_get_optipng_binary());
	}

	/**
	 * Set path to the "optipng" binary we should use.
	 */
	public static void setOptipngBinary(string path)
	{
		asc_globals_set_optipng_binary(Str.toStringz(path));
	}

	/**
	 * Register a new hint tag. If a previous tag with the given name
	 * already existed, the existing tag will not be replaced unless
	 * @overrideExisting is set to %TRUE.
	 * Please be careful when overriding tags! Tag severities can not
	 * be lowered by overriding a tag.
	 *
	 * Params:
	 *     tag = the tag-ID to add
	 *     severity = the tag severity as #AsIssueSeverity
	 *     explanation = the tag explanatory message
	 *     overrideExisting = whether an existing tag should be replaced
	 *
	 * Returns: %TRUE if the tag was registered and did not exist previously.
	 */
	public static bool addHintTag(string tag, AsIssueSeverity severity, string explanation, bool overrideExisting)
	{
		return asc_globals_add_hint_tag(Str.toStringz(tag), severity, Str.toStringz(explanation), overrideExisting) != 0;
	}

	/**
	 * Retrieve all hint tags that we know.
	 *
	 * Returns: A list of valid hint tags. Free with %g_strfreev
	 */
	public static string[] getHintTags()
	{
		auto retStr = asc_globals_get_hint_tags();

		scope(exit) Str.freeStringArray(retStr);
		return Str.toStringArray(retStr);
	}

	/**
	 * Retrieve the severity of the given hint tag.
	 *
	 * Returns: An #AsIssueSeverity or %AS_ISSUE_SEVERITY_UNKNOWN if the tag did not exist
	 *     or has an unknown severity.
	 */
	public static AsIssueSeverity hintTagSeverity(string tag)
	{
		return asc_globals_hint_tag_severity(Str.toStringz(tag));
	}

	/**
	 * Retrieve the explanation template of the given hint tag.
	 *
	 * Returns: An explanation template, or %NULL if the tag was not found.
	 */
	public static string hintTagExplanation(string tag)
	{
		return Str.toString(asc_globals_hint_tag_explanation(Str.toStringz(tag)));
	}
}
