/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module ascompose.Hint;

private import ascompose.c.functions;
public  import ascompose.c.types;
private import glib.ConstructionException;
private import glib.ErrorG;
private import glib.GException;
private import glib.PtrArray;
private import glib.Str;
private import gobject.ObjectG;


/** */
public class Hint : ObjectG
{
	/** the main Gtk struct */
	protected AscHint* ascHint;

	/** Get the main Gtk struct */
	public AscHint* getHintStruct(bool transferOwnership = false)
	{
		if (transferOwnership)
			ownedRef = false;
		return ascHint;
	}

	/** the main Gtk struct as a void* */
	protected override void* getStruct()
	{
		return cast(void*)ascHint;
	}

	/**
	 * Sets our main struct and passes it to the parent class.
	 */
	public this (AscHint* ascHint, bool ownedRef = false)
	{
		this.ascHint = ascHint;
		super(cast(GObject*)ascHint, ownedRef);
	}


	/** */
	public static GType getType()
	{
		return asc_hint_get_type();
	}

	/**
	 * Creates a new #AscHint.
	 *
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this()
	{
		auto __p = asc_hint_new();

		if(__p is null)
		{
			throw new ConstructionException("null returned by new");
		}

		this(cast(AscHint*) __p, true);
	}

	/**
	 * Creates a new #AscHint with the given tag. If the selected tag was not registered+
	 * with the global tag registry, %NULL is returned and an error is set.
	 *
	 * Params:
	 *     tag = The tag ID to construct this hint for.
	 *
	 * Throws: GException on failure.
	 * Throws: ConstructionException GTK+ fails to create the object.
	 */
	public this(string tag)
	{
		GError* err = null;

		auto __p = asc_hint_new_for_tag(Str.toStringz(tag), &err);

		if (err !is null)
		{
			throw new GException( new ErrorG(err) );
		}

		if(__p is null)
		{
			throw new ConstructionException("null returned by new_for_tag");
		}

		this(cast(AscHint*) __p, true);
	}

	/**
	 * Add a replacement variable for the explanation text.
	 *
	 * Params:
	 *     varName = Name of the variable to be replaced.
	 *     text = Replacement for the variable name.
	 */
	public void addExplanationVar(string varName, string text)
	{
		asc_hint_add_explanation_var(ascHint, Str.toStringz(varName), Str.toStringz(text));
	}

	/**
	 * Formats the explanation template to return a human-redable issue hint
	 * explanation, with all placeholder variables replaced.
	 *
	 * Returns: Explanation text for this hint, with variables replaced.
	 */
	public string formatExplanation()
	{
		auto retStr = asc_hint_format_explanation(ascHint);

		scope(exit) Str.freeString(retStr);
		return Str.toString(retStr);
	}

	/**
	 * Gets the explanation template for this hint.
	 */
	public string getExplanationTemplate()
	{
		return Str.toString(asc_hint_get_explanation_template(ascHint));
	}

	/**
	 * Returns a list with the flattened key/value pairs for this hint.
	 * Values are located in uneven list entries, following their keys in even list entries.
	 *
	 * Returns: A flattened #GPtrArray with the key/value pairs.
	 */
	public PtrArray getExplanationVarsList()
	{
		auto __p = asc_hint_get_explanation_vars_list(ascHint);

		if(__p is null)
		{
			return null;
		}

		return new PtrArray(cast(GPtrArray*) __p);
	}

	/**
	 * Gets the issue severity of this hint.
	 */
	public AsIssueSeverity getSeverity()
	{
		return asc_hint_get_severity(ascHint);
	}

	/**
	 * Gets the unique tag for the type of this hint.
	 */
	public string getTag()
	{
		return Str.toString(asc_hint_get_tag(ascHint));
	}

	/**
	 * Returns: %TRUE if this hint describes an error.
	 */
	public bool isError()
	{
		return asc_hint_is_error(ascHint) != 0;
	}

	/**
	 * Check if this hint is valid (it requires at least a tag and a severity
	 * in order to be considered valid).
	 *
	 * Returns: %TRUE if this hint is valid.
	 */
	public bool isValid()
	{
		return asc_hint_is_valid(ascHint) != 0;
	}

	/**
	 * Sets the explanation template for this hint.
	 */
	public void setExplanationTemplate(string explanationTmpl)
	{
		asc_hint_set_explanation_template(ascHint, Str.toStringz(explanationTmpl));
	}

	/**
	 * Sets the issue severity of this hint.
	 */
	public void setSeverity(AsIssueSeverity severity)
	{
		asc_hint_set_severity(ascHint, severity);
	}

	/**
	 * Sets the unique tag for the type of this hint.
	 */
	public void setTag(string tag)
	{
		asc_hint_set_tag(ascHint, Str.toStringz(tag));
	}
}
