/*
 * Licensed under the GNU Lesser General Public License Version 3
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the license, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

// generated automatically - do not change


module ascompose.MetaInfoUtils;

private import appstream.Component;
private import appstream.Metadata;
private import appstream.Validator;
private import ascompose.Result;
private import ascompose.c.functions;
public  import ascompose.c.types;
private import glib.Bytes;
private import glib.Str;
private import gobject.ObjectG;


/** */
public struct MetaInfoUtils
{

	/**
	 * Parses metaInfo XML into a new #AsComponent and records any issues in
	 * an #AscResult.
	 *
	 * Params:
	 *     cres = an #AscResult instance.
	 *     mdata = an #AsMetadata instance used for parsing.
	 *     bytes = the data to parse.
	 *     miBasename = the basename of the MetaInfo file we are loading.
	 *
	 * Returns: A new #AsComponent or %NULL if we refused to accept this data.
	 */
	public static Component parseMetainfoData(Result cres, Metadata mdata, Bytes bytes, string miBasename)
	{
		auto __p = asc_parse_metainfo_data((cres is null) ? null : cres.getResultStruct(), (mdata is null) ? null : mdata.getMetadataStruct(), (bytes is null) ? null : bytes.getBytesStruct(), Str.toStringz(miBasename));

		if(__p is null)
		{
			return null;
		}

		return ObjectG.getDObject!(Component)(cast(AsComponent*) __p, true);
	}

	/**
	 * Parses metaInfo XML into a new #AsComponent and records any issues in
	 * an #AscResult.
	 *
	 * Params:
	 *     cres = an #AscResult instance.
	 *     bytes = the data to parse.
	 *     miBasename = the basename of the MetaInfo file we are loading.
	 *
	 * Returns: A new #AsComponent or %NULL if we refused to accept this data.
	 */
	public static Component parseMetainfoDataSimple(Result cres, Bytes bytes, string miBasename)
	{
		auto __p = asc_parse_metainfo_data_simple((cres is null) ? null : cres.getResultStruct(), (bytes is null) ? null : bytes.getBytesStruct(), Str.toStringz(miBasename));

		if(__p is null)
		{
			return null;
		}

		return ObjectG.getDObject!(Component)(cast(AsComponent*) __p, true);
	}

	/**
	 * Validates MetaInfo data for the given component and stores the validation result as issue hints
	 * in the given #AscResult.
	 * Both the result as well as the validator's state may be modified by this function.
	 *
	 * Params:
	 *     cres = an #AscResult instance.
	 *     validator = an #AsValidator to validate with.
	 *     cpt = the loaded #AsComponent which we are validating
	 *     bytes = the data @cpt was constructed from.
	 *     miBasename = the basename of the MetaInfo file we are analyzing.
	 */
	public static void validateMetainfoDataForComponent(Result cres, Validator validator, Component cpt, Bytes bytes, string miBasename)
	{
		asc_validate_metainfo_data_for_component((cres is null) ? null : cres.getResultStruct(), (validator is null) ? null : validator.getValidatorStruct(), (cpt is null) ? null : cpt.getComponentStruct(), (bytes is null) ? null : bytes.getBytesStruct(), Str.toStringz(miBasename));
	}

	/**
	 * Parse a XDG desktop-entry file into either a new component or for extending an existing component.
	 *
	 * Params:
	 *     cres = an #AscResult instance.
	 *     cpt = an existing #AsComponent which we are adding data from this desktop file to, or NULL to create a new one
	 *     bytes = the data @cpt was constructed from.
	 *     deBasename = the basename of the desktop-entry file we are parsing.
	 *     ignoreNodisplay = set %TRUE if fields which cause the desktop-entry file to be purposefully hidden should be ignored (useful when passing an existing #AsComponent).
	 *     fversion = AppStream format version
	 *     deL10nFn = callback for custom desktop-entry field localization functions.
	 *     userData = user data for @de_l10n_fn
	 *
	 * Returns: A new #AsComponent or reference to the existing #AsComponent passed as parameter in case
	 *     we parsed anything. %NULL if we refused to accept this data.
	 */
	public static Component parseDesktopEntryData(Result cres, Component cpt, Bytes bytes, string deBasename, bool ignoreNodisplay, AsFormatVersion fversion, AscTranslateDesktopTextFn deL10nFn, void* userData)
	{
		auto __p = asc_parse_desktop_entry_data((cres is null) ? null : cres.getResultStruct(), (cpt is null) ? null : cpt.getComponentStruct(), (bytes is null) ? null : bytes.getBytesStruct(), Str.toStringz(deBasename), ignoreNodisplay, fversion, deL10nFn, userData);

		if(__p is null)
		{
			return null;
		}

		return ObjectG.getDObject!(Component)(cast(AsComponent*) __p, true);
	}
}
